@@ -12,4 +12,6 @@ class PageModel(BaseModel):
     node: str
     name: str
     root: str
+    perms: list[str]
+    perms_ext: list[str]
 
