@@ -27,8 +27,11 @@ class NationService:
                 return None
             
             json_data = response.json()
-            result_data = dict(json_data).get("data", [None])
+            result_data = dict(json_data).get("results", [None])
             model_data = result_data[0]
+            
+            if not model_data:
+                return None
 
             nation_model = NationModel(**model_data)
             self.cache.set(model=nation_model, timeout=60 * 60 * 24)
